
Data Classes
==========

.. autoclass:: befordata.BeForRecord
   :members:
   :member-order: bysource

.. autoclass:: befordata.BeForEpochs
   :members:
   :member-order: bysource


Module: tools
================

.. autofunction:: befordata.tools.detect_sessions

.. autofunction:: befordata.tools.butter_filter


Module: csv
==============

.. autofunction:: befordata.csv.read_csv_as_befordata

.. autofunction:: befordata.csv.read_csv



